```{eval-rst}
.. _time-series-api:
```
# Time Series

```{eval-rst}
.. autopydantic_model:: infrasys.time_series_models.TimeSeriesData
   :members:
```

```{eval-rst}
.. _singe-time-series-api:
```

```{eval-rst}
.. autopydantic_model:: infrasys.time_series_models.SingleTimeSeries
   :members:
```
